/*
 * (c) Copyright 2011 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.model;

import java.sql.Connection;

import org.databene.commons.iterator.TableRowIterator;
import org.databene.jdbacl.model.Database;

/**
 * Proxy class for the {@link CheckStrategy} interface.<br/><br/>
 * Created: 05.11.2011 09:33:09
 * @since 1.0
 * @author Volker Bergmann
 */
public class CheckStrategyProxy extends AbstractCheckStrategy {
	
	protected CheckStrategy realStrategy;

	public CheckStrategyProxy(CheckStrategy realStrategy) {
		this.realStrategy = realStrategy;
	}

	public String getDetails() {
		return (realStrategy != null ? realStrategy.getDetails() : null);
	}

	public TableRowIterator perform(Connection connection, Database database) {
		if (realStrategy == null)
			throw new IllegalStateException("realStrategy has not been set in " + this);
		return realStrategy.perform(connection, database);
	}

	public long getDefectCount() {
		return (realStrategy != null ? realStrategy.getDefectCount() : 0);
	}

	public void reset() {
		if (realStrategy != null)
			realStrategy.reset();
	}
	
	public CheckStrategy getRealStrategy() {
		return realStrategy;
	}

}
