/*
 * (c) Copyright 2011 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.model;

import java.io.File;

import org.databene.commons.iterator.TableRowIterator;
import org.databene.commons.math.Intervals;
import org.databene.commons.version.VersionNumber;

/**
 * {@link SanityCheck} implementation which uses a {@link CheckStrategy} to perform the check.<br/><br/>
 * Created: 26.10.2011 18:22:54
 * @since 0.9.0
 * @author Volker Bergmann
 */
public class StrategyBasedCheck extends SanityCheck {
	
	private CheckStrategy strategy;

	public StrategyBasedCheck(String name, String table,
			Intervals<VersionNumber> intervalCollection, String defectType, 
			File sourceFile, File tempFolder, File reportFolder, File docPage) {
		super(name, table, intervalCollection, defectType, sourceFile, tempFolder, reportFolder, docPage);
	}
	
	public CheckStrategy getStrategy() {
		return strategy;
	}
	
	public void setStrategy(CheckStrategy strategy) {
		this.strategy = strategy;
	}
	
	@Override
	public String getDetails() {
		return strategy.getDetails();
	}
	
	@Override
	public void reset() {
		strategy.reset();
		fireStatusChanged();
	}

	@Override
	public TableRowIterator perform(CheckContext checkContext) {
		try {
			TableRowIterator iterator = strategy.perform(checkContext.getConnection(), checkContext.getDatabase());
			this.verdict = (iterator.hasNext() ? SanityCheckVerdict.FAILED : SanityCheckVerdict.PASSED);
			return iterator;
		} catch (RuntimeException e) {
			this.verdict = SanityCheckVerdict.ERROR;
			throw e;
		} finally {
			fireStatusChanged();
		}
	}

	@Override
	public long getDefectCount() {
		return strategy.getDefectCount();
	}

}
